@@ -1,9 +1,8 @@
+import glob
 import os
 import sys
-import glob
-
-from pathlib import Path
 from importlib import import_module
+from pathlib import Path
 
 import bsl
 
@@ -11,10 +10,10 @@ import bsl
 def run():
     """Entrypoint for bsl <command> usage."""
     bsl_root = Path(__file__).parent.parent
-    valid_commands = sorted(
-        glob.glob(str(bsl_root/'commands'/'bsl_*.py')))
-    valid_commands = [file.split(os.path.sep)[-1][4:-3]
-                      for file in valid_commands]
+    valid_commands = sorted(glob.glob(str(bsl_root / "commands" / "bsl_*.py")))
+    valid_commands = [
+        file.split(os.path.sep)[-1][4:-3] for file in valid_commands
+    ]
 
     def print_help():
         print("Usage: BrainStreamingLayer command options\n")
@@ -33,6 +32,6 @@ def run():
         print_help()
     else:
         cmd = sys.argv[1]
-        cmd = import_module('.bsl_%s' % (cmd,), 'bsl.commands')
+        cmd = import_module(".bsl_%s" % (cmd,), "bsl.commands")
         sys.argv = sys.argv[1:]
         cmd.run()
