@@ -1,23 +1,22 @@
-import os
-import time
-import pickle
 import datetime
-from pathlib import Path
 import multiprocessing as mp
+import os
+import pickle
+import time
+from pathlib import Path
 
-from ..utils import Timer
-from ..utils.io import pcl2fif
-from ..utils._logs import logger
-from ..utils._docs import fill_doc
-from ..utils._checks import _check_type
-from ..stream_receiver import StreamReceiver, StreamEEG
+from ..stream_receiver import StreamEEG, StreamReceiver
 from ..stream_receiver._stream import MAX_BUF_SIZE
+from ..utils import Timer
+from ..utils._checks import _check_type
+from ..utils._docs import fill_doc
+from ..utils._logs import logger
+from ..utils.io import pcl2fif
 
 
 @fill_doc
 class StreamRecorder:
-    """
-    Class for recording the signals coming from LSL streams.
+    """Class for recording the signals coming from LSL streams.
 
     Parameters
     ----------
@@ -28,41 +27,57 @@ class StreamRecorder:
     %(recorder_verbose)s
     """
 
-    def __init__(self, record_dir=None, fname=None, stream_name=None,
-                 fif_subdir=True, *, verbose=False):
+    def __init__(
+        self,
+        record_dir=None,
+        fname=None,
+        stream_name=None,
+        fif_subdir=True,
+        *,
+        verbose=False,
+    ):
         self._record_dir = StreamRecorder._check_record_dir(record_dir)
         self._fname = StreamRecorder._check_fname(fname)
-        _check_type(stream_name, (None, str, list, tuple),
-                    item_name='stream_name')
+        _check_type(
+            stream_name, (None, str, list, tuple), item_name="stream_name"
+        )
         self._stream_name = stream_name
-        _check_type(fif_subdir, (bool, ), item_name='fif_subdir')
+        _check_type(fif_subdir, (bool,), item_name="fif_subdir")
         self._fif_subdir = fif_subdir
-        _check_type(verbose, (bool, ), item_name='verbose')
+        _check_type(verbose, (bool,), item_name="verbose")
         self._verbose = verbose
 
         self._eve_file = None  # for SOFTWARE triggers
         self._process = None
-        self._state = mp.Value('i', 0)
+        self._state = mp.Value("i", 0)
 
-    def start(self, blocking=True):
-        """
-        Start the recording in a new process.
+    def start(self, blocking=True) -> None:
+        """Start the recording in a new process.
 
         Parameters
         ----------
         blocking : bool
             If ``True``, waits for the child process to start recording data.
         """
-        _check_type(blocking, (bool, ), item_name='blocking')
+        _check_type(blocking, (bool,), item_name="blocking")
         fname, self._eve_file = StreamRecorder._create_fname(
-            self._record_dir, self._fname)
+            self._record_dir, self._fname
+        )
         logger.debug("File name stem is '%s'.", fname)
         logger.debug("Event file name is '%s'.", self._eve_file)
 
         self._process = mp.Process(
             target=self._record,
-            args=(self._record_dir, fname, self._stream_name, self._fif_subdir,
-                  self._verbose, self._eve_file, self._state))
+            args=(
+                self._record_dir,
+                fname,
+                self._stream_name,
+                self._fif_subdir,
+                self._verbose,
+                self._eve_file,
+                self._state,
+            ),
+        )
         self._process.start()
 
         if blocking:
@@ -71,36 +86,49 @@ class StreamRecorder:
 
         logger.info(self.__repr__())
 
-    def stop(self):
-        """
-        Stops the recording.
-        """
+    def stop(self) -> None:
+        """Stop the recording."""
         if self._process is None:
-            logger.warning('StreamRecorder was not started. Skipping.')
+            logger.warning("StreamRecorder was not started. Skipping.")
             return
 
         with self._state.get_lock():
             self._state.value = 0
 
-        logger.info('Waiting for StreamRecorder process to finish.')
+        logger.info("Waiting for StreamRecorder process to finish.")
         self._process.join(10)
         if self._process.is_alive():
-            logger.error('Recorder process not finishing..')
+            logger.error("Recorder process not finishing..")
             self._process.kill()
             raise RuntimeError
-        logger.info('Recording finished.')
+        logger.info("Recording finished.")
 
         self._eve_file = None
         self._process = None
 
-    def _record(self, record_dir, fname, stream_name, fif_subdir, verbose,
-                eve_file, state):
+    def _record(
+        self,
+        record_dir,
+        fname,
+        stream_name,
+        fif_subdir,
+        verbose,
+        eve_file,
+        state,
+    ):  # noqa: D401
+        """Function called in the new process.
+
+        Instantiate a _Recorder and start recording.
         """
-        The function called in the new process.
-        Instance a _Recorder and start recording.
-        """
-        recorder = _Recorder(record_dir, fname, stream_name, fif_subdir,
-                             verbose, eve_file, state)
+        recorder = _Recorder(
+            record_dir,
+            fname,
+            stream_name,
+            fif_subdir,
+            verbose,
+            eve_file,
+            state,
+        )
         recorder.record()
 
     # --------------------------------------------------------------------
@@ -114,19 +142,22 @@ class StreamRecorder:
 
     def __repr__(self):
         """Representation of the instance."""
-        status = 'ON' if self._state.value == 1 else 'OFF'
-        streams = self._stream_name if self._stream_name is not None \
-            else 'All streams'
-        return f'<Recorder: {streams} | {status} | {self._record_dir}>'
+        status = "ON" if self._state.value == 1 else "OFF"
+        streams = (
+            self._stream_name
+            if self._stream_name is not None
+            else "All streams"
+        )
+        return f"<Recorder: {streams} | {status} | {self._record_dir}>"
 
     # --------------------------------------------------------------------
     @staticmethod
-    def _check_record_dir(record_dir):
+    def _check_record_dir(record_dir):  # noqa
         """
-        Converts record_dir to a Path, or select the current working directory
+        Convert record_dir to a Path, or select the current working directory
         if record_dir is None.
         """
-        _check_type(record_dir, (None, 'path-like'), item_name='record_dir')
+        _check_type(record_dir, (None, "path-like"), item_name="record_dir")
         if record_dir is None:
             record_dir = Path.cwd()
         else:
@@ -135,28 +166,26 @@ class StreamRecorder:
 
     @staticmethod
     def _check_fname(fname):
-        """
-        Checks that the file name stem is a string or None.
-        """
-        _check_type(fname, (None, str), item_name='fname')
+        """Check that the file name stem is a string or None."""
+        _check_type(fname, (None, str), item_name="fname")
         return fname
 
     @staticmethod
     def _create_fname(record_dir, fname):
-        """
-        Creates the file name path using the current datetime if fname is None.
-        """
-        fname = fname if fname is not None \
-            else time.strftime('%Y%m%d-%H%M%S', time.localtime())
-        eve_file = record_dir / f'{fname}-eve.txt'
+        """Create the file name path from the datetime if fname is None."""
+        fname = (
+            fname
+            if fname is not None
+            else time.strftime("%Y%m%d-%H%M%S", time.localtime())
+        )
+        eve_file = record_dir / f"{fname}-eve.txt"
 
         return fname, eve_file
 
     # --------------------------------------------------------------------
     @property
     def record_dir(self):
-        """
-        Path to the directory where data will be saved.
+        """Path to the directory where data will be saved.
 
         :type: Path
         """
@@ -164,10 +193,10 @@ class StreamRecorder:
 
     @property
     def fname(self):
-        """
-        File name stem used to create the files. The StreamRecorder creates 2
-        files plus an optional third if a software trigger was used, respecting
-        the following naming:
+        """File name stem used to create the files.
+
+        The StreamRecorder creates 2 files plus an optional third if a software
+        trigger was used, respecting the following naming:
 
         .. code-block:: python
 
@@ -240,7 +269,7 @@ class StreamRecorder:
 
 
 @fill_doc
-class _Recorder:
+class _Recorder:  # noqa
     """
     Class creating the .pcl files, recording data through a StreamReceiver and
     saving the data in the .pcl and .fif files.
@@ -261,8 +290,16 @@ class _Recorder:
         Path to the event file for SoftwareTrigger.
     """
 
-    def __init__(self, record_dir, fname, stream_name, fif_subdir, verbose,
-                 eve_file, state):
+    def __init__(
+        self,
+        record_dir,
+        fname,
+        stream_name,
+        fif_subdir,
+        verbose,
+        eve_file,
+        state,
+    ):
         self._record_dir = record_dir
         self._fname = fname
         self._stream_name = stream_name
@@ -272,11 +309,10 @@ class _Recorder:
         self._state = state
 
     def record(self):
-        """
-        Instantiate a StreamReceiver, create the files, record and save.
-        """
+        """Instantiate a StreamReceiver, create the files, record and save."""
         sr = StreamReceiver(
-            bufsize=MAX_BUF_SIZE, stream_name=self._stream_name)
+            bufsize=MAX_BUF_SIZE, stream_name=self._stream_name
+        )
         pcl_files = _Recorder._create_files(self._record_dir, self._fname, sr)
 
         with self._state.get_lock():
@@ -293,40 +329,40 @@ class _Recorder:
             if self._verbose:
                 if verbose_timer.sec() - previous_time >= 1:
                     previous_time = verbose_timer.sec()
-                    duration = str(datetime.timedelta(
-                        seconds=int(verbose_timer.sec())))
-                    logger.info('RECORDING %s', duration)
+                    duration = str(
+                        datetime.timedelta(seconds=int(verbose_timer.sec()))
+                    )
+                    logger.info("RECORDING %s", duration)
 
         self._save(sr, pcl_files)
 
     def _save(self, sr, pcl_files):
-        """
-        Save the data in the StreamReceiver buffer to the .pcl and .fif files.
-        """
-        logger.info('Saving raw data..')
+        """Save the data in the receiver's buffer to the files."""
+        logger.info("Saving raw data..")
         for stream in sr.streams:
             signals, timestamps = sr.get_buffer(stream)
 
             if isinstance(sr.streams[stream], StreamEEG):
-                signals[:, 1:] *= 1E-6
+                signals[:, 1:] *= 1e-6
 
             data = {
-                'signals': signals,
-                'timestamps': timestamps,
-                'events': None,
-                'sample_rate': sr.streams[stream].sample_rate,
-                'channels': len(sr.streams[stream].ch_list),
-                'ch_names': sr.streams[stream].ch_list,
-                'lsl_time_offset': sr.streams[stream].lsl_time_offset}
+                "signals": signals,
+                "timestamps": timestamps,
+                "events": None,
+                "sample_rate": sr.streams[stream].sample_rate,
+                "channels": len(sr.streams[stream].ch_list),
+                "ch_names": sr.streams[stream].ch_list,
+                "lsl_time_offset": sr.streams[stream].lsl_time_offset,
+            }
 
-            with open(pcl_files[stream], 'wb') as file:
+            with open(pcl_files[stream], "wb") as file:
                 pickle.dump(data, file, protocol=pickle.HIGHEST_PROTOCOL)
 
             logger.info("Saved to '%s'", pcl_files[stream])
 
             if not isinstance(sr.streams[stream], StreamEEG):
                 continue
-            logger.info('Converting raw files into fif.')
+            logger.info("Converting raw files into fif.")
 
             if self._fif_subdir:
                 out_dir = None
@@ -334,36 +370,37 @@ class _Recorder:
                 out_dir = self._record_dir
 
             if self._eve_file.exists():
-                logger.info('Found matching event file, adding events.')
+                logger.info("Found matching event file, adding events.")
                 pcl2fif(
-                    pcl_files[stream], out_dir, external_event=self._eve_file)
+                    pcl_files[stream], out_dir, external_event=self._eve_file
+                )
             else:
-                pcl2fif(
-                    pcl_files[stream], out_dir, external_event=None)
+                pcl2fif(pcl_files[stream], out_dir, external_event=None)
 
     # --------------------------------------------------------------------
     @staticmethod
     def _create_files(record_dir, fname, sr):
-        """
-        Create the .pcl files and check writability.
-        """
+        """Create the .pcl files and check writability."""
         os.makedirs(record_dir, exist_ok=True)
 
         pcl_files = dict()
         for stream in sr.streams:
-            pcl_files[stream] = \
-                record_dir / f'{fname}-{stream}-raw.pcl'
+            pcl_files[stream] = record_dir / f"{fname}-{stream}-raw.pcl"
 
             try:
-                with open(pcl_files[stream], 'w') as file:
+                with open(pcl_files[stream], "w") as file:
                     file.write(
-                        'Data will be written when the recording is finished.')
+                        "Data will be written when the recording is finished."
+                    )
             except Exception as error:
-                raise error("Could not write to '%s'. Check permissions"
-                            % {pcl_files[stream]})
+                raise error(
+                    "Could not write to '%s'. Check permissions"
+                    % {pcl_files[stream]}
+                )
 
         logger.info(
-            'Record to files: \n' +
-            '\n'.join(str(file) for file in pcl_files.values()))
+            "Record to files: \n"
+            + "\n".join(str(file) for file in pcl_files.values())
+        )
 
         return pcl_files
